#! /bin/sh

### lo0 Route Controller ######################################################
#                                                                             #
#  Usage : lo0route.sh {-add | -del[ete]} {-i ipaddress | -f filename}        #
#                                                                             #
#  (ipaddress): new IP address                                                #
#  (filename) : filename to remember the current IP address                   #
#  If you want to delele the current IP address file, specify "DELETE" as     #
#  the new IP address.                                                        #
#                                                                             #
###############################################################################


# =============================================================================
# Definition
# =============================================================================
#
# ----- define common variables and functions -----
. /usr/local/richscripts/etc/common.lib


# =============================================================================
# Parse the arguments
# -----------------------------------------------------------------------------
#  1. parse the new IP address
#  2. parse the file to remember the current IP address
#  3. show help message and exit if not enough argument
# =============================================================================
#
# ----- 1. 2. parse ipaddress and filename -----
arg_switch=""
for arg in $*
do
  if [ -z "${arg%%-*}" ]; then
    arg=${arg##*-}
    arg_switch=""
    if [ "$arg" = "add" ]; then
      command="ADD"
    elif [ \( "$arg" = "delete" \) -o \( "$arg" = "del" \) ]; then
      command="DELETE"
    else
      arg_switch="$arg"
    fi
  elif [ "$arg_switch" = "i" ]; then
    check=`echo $arg | $CMD_GREP -E $PATTERN_IPV4`
    if [ -n "$check" ]; then
      ip_addr="$check"
    fi
    arg_switch=""
  elif [ "$arg_switch" = "f" ]; then
    if [ -f $DIR_RICHSCRIPTS/etc/$arg ]; then
      check=`cat $DIR_RICHSCRIPTS/etc/$arg | $CMD_GREP -E $PATTERN_IPV4`
      if [ -n "$check" ]; then
        ip_addr="$check"
      fi
    fi
    arg_switch=""
  fi
done
# ----- 3. show help message and exit if the arguments are not enough -----
if [ \( -z "$ip_addr" \) -o \( -z "$command" \) ]; then
  echo "Usage : ${0##*/} {-add | -del[ete]} {-i ipaddress | -f filename}"
  echo "- You must specify the command \"-add\" or \"-delete\"."
  echo "- nameserver must be the x.x.x.x style. And filename must be pure"
  echo "  filename which include the same style IP address."
  debug_log "lo0route.sh: the arguments are not enough"
  exit
fi


# =============================================================================
# Add lo0 route
# -----------------------------------------------------------------------------
#  1. command determination
#  2. OS determination
#  3. execute each route command
# =============================================================================
#
# --- 1. command determination ---
if [ $command = "ADD" ]; then
  # --- 2. OS determination ---
  case $OS_TYPE in
    # --- 3. execute each route command ---
    FreeBSD)
      $CMD_ROUTE add -host $ip_addr -interface lo0 > /dev/null
      ;;
    Linux)
      $CMD_ROUTE add -host $ip_addr dev lo > /dev/null
      ;;
  esac
fi


# =============================================================================
# Delete lo0 route
# -----------------------------------------------------------------------------
#  1. command determination
#  2. OS determination
#  3. execute each route command
# =============================================================================
#
# --- 1. command determination ---
if [ $command = "DELETE" ]; then
  # --- 2. OS determination ---
  case $OS_TYPE in
    # --- 3. execute each route command ---
    FreeBSD)
      $CMD_ROUTE delete -host $ip_addr -interface lo0 > /dev/null
      ;;
    Linux)
      $CMD_ROUTE del -host $ip_addr dev lo > /dev/null
      ;;
  esac
fi
