#! /bin/sh

### Updated IP address Register ###############################################
#                                                                             #
#  Usage : updateip.sh -i ipaddress -f filename                               #
#                                                                             #
#  (ipaddress): new IP address                                                #
#  (filename) : filename to remember the current IP address                   #
#  If you want to delele the current IP address file, specify "DELETE" as     #
#  the new IP address.                                                        #
#                                                                             #
###############################################################################


# =============================================================================
# Definition
# =============================================================================
#
# ----- define common variables and functions -----
. /usr/local/richscripts/etc/common.lib


# =============================================================================
# Parse the arguments
# -----------------------------------------------------------------------------
#  1. parse the new IP address
#  2. parse the file to remember the current IP address
#  3. show help message and exit if not enough argument
# =============================================================================
#
# ----- 1. 2. parse ipaddress and filename -----
arg_switch=""
for arg in $*
do
  if [ "$arg_switch" = "" ]; then
    arg_switch="$arg"
  elif [ "$arg_switch" = "-i" ]; then
    arg_switch=""
    check=`echo $arg | $CMD_GREP -E $PATTERN_IPV4`
    if [ -n "$check" ]; then
      new_ip_addr="$arg"
    else
      case "$arg" in
        [Dd][Ee][Ll][Ee][Tt][Ee])
          new_ip_addr="DELETE"
          ;;
      esac
    fi
  elif [ "$arg_switch" = "-f" ]; then
    arg_switch=""
    check=`echo $arg | $CMD_GREP -v /`
    if [ -n "$check" ]; then
      file_cur_ip_addr="$arg"
    fi
  fi
done
# ----- 3. show help message and exit if the arguments are not enough -----
if [ \( -z "$new_ip_addr" \) -o \( -z "$file_cur_ip_addr" \) ]; then
  echo "Usage : ${0##*/} -i ipaddress -f filename"
  echo "- ipaddress must be the x.x.x.x style. And filename must be pure"
  echo "  filename."
  debug_log "updateip.sh: the arguments are not enough"
  exit
fi


# =============================================================================
# Boot OpenVPN if required
# =============================================================================
#
if [ \( -n "$use_openvpn" \) -a \( "$file_cur_ip_addr" = "$FILE_CURRENT_IP" \) ]
then
  case "$use_openvpn" in
    [Yy][Ee][Ss])
      if [ "$new_ip_addr" != "DELETE" ]; then
        $PATH_BOOTOVPN start
      else
        $PATH_BOOTOVPN stop
      fi
      ;;
    *)
      ;;
  esac
fi


# =============================================================================
# Check and update IP address file
# -----------------------------------------------------------------------------
#  Compare current and new IP address for checking whether need to update or
#  not at first. If need, update the file and keep the registry in the
#  remembering file. Otherwise, delete registry the remembering filename.
# =============================================================================
#
# --- define temporary files
curfile="$DIR_RICHSCRIPTS/etc/$file_cur_ip_addr"
oldfile="$curfile.old"
newfile="$curfile.new"
if [ "$new_ip_addr" != "DELETE" ]; then
  # --- save old IP address file
  if [ -f "$curfile" ]; then
    $CMD_CAT $curfile > $oldfile
  else
    echo -n > $oldfile
  fi
  # --- create the new IP address file
  echo "$new_ip_addr" > $newfile
  # --- check whether the file is updated or not
  $CMD_CAT $newfile | $CMD_DIFF --brief - $oldfile > /dev/null
  if [ $? -eq 1 ]; then
    check="KEEP"
  else
    check="DISCARD"
  fi
else
  if [ -f "$curfile" ]; then
    $CMD_RM -f $curfile
    check="KEEP"
  else
    check="DISCARD"
  fi
fi
# --- keep the filename and overwrite current file when updated
#     otherwise delete the new file
if [ "$check" = "KEEP" ]; then
  [ -f "$newfile" ] && $CMD_MV -f $newfile $curfile
else
  file_cur_ip_addr=""
  [ -f "$newfile" ] && $CMD_RM -f $newfile
fi
# --- the old server list file will be delete
[ -f "$oldfile" ] && $CMD_RM -f $oldfile


# =============================================================================
# Re-register firewall rule
# -----------------------------------------------------------------------------
#  At first, check the following condensations
#  1. The remembering file are updated (It is evident with checking whether
#     $file_cur_ip_addr is NULL or not.)
#  #2. This script called not when OS booting
#
#  If both condensations are sutisfied,
#  3. Re-register firewall rule
#  4. Re-register DDNS
# =============================================================================
#
# ----- 1. Check whether the remembering file is updated -----
if [ -z "$file_cur_ip_addr" ]; then
  exit
fi
# ----- 2. Check whether this script called not when OS booting -----
#check=`$CMD_PS ax | $CMD_GREP -v ${CMD_GREP##*/} | $CMD_GREP "sh /etc/rc autoboot"`
#if [ -n "$check" ]; then
#  exit
#fi
# ----- 3. Re-register firewall rule -----
$PATH_REGFW -t $chosen_fw -q YES
# ----- 4. Re-register DDNS -----
case $new_ip_addr in
  DELETE)
    ;;
  10.*)
    ;;
  172.1[6-9].*)
    ;;
  172.2[0-9].*)
    ;;
  172.3[01].*)
    ;;
  192.168.*)
    ;;
  *)
    $PATH_REGDDNS -i $new_ip_addr &
    ;;
esac
